@@ -12,7 +12,7 @@ use Log::Log4perl qw(:easy);
 use Number::Bytes::Human qw( format_bytes parse_bytes );
 
 # ABSTRACT: Yet Another RESTful-Archive Service
-our $VERSION = '1.21'; # VERSION
+our $VERSION = '1.22'; # VERSION
 
 
 has secret => rand;
@@ -201,7 +201,7 @@ Yars - Yet Another RESTful-Archive Service
 
 =head1 VERSION
 
-version 1.21
+version 1.22
 
 =head1 SYNOPSIS
 
@@ -238,6 +238,11 @@ Download a file
 
 Yars is a simple RESTful server for data storage.
 
+Properly configured it provides consistent WRITE availability,
+and eventual READ availability.  Once files are written to
+the storage cluster they are immutable (new files can -- even
+with the same filename) can also be written to the cluster.
+
 It allows files to be PUT and GET based on their md5 sums
 and filenames, and uses a distributed hash table to store
 the files across any number of hosts and disks.
@@ -667,6 +672,13 @@ C<wget>, the MD5 check will still happen on the server
 side.  You may request this check be skipped by setting
 the C<X-Yars-Skip-Verify> header to any value.
 
+=head1 ACKNOWLEDGEMENT
+
+Thanks to Brian Duggan (BDUGGAN) for doing most of the initial
+work on Yars, and David Golden (XDG, DAGOLDEN) for describing
+Yars strength as "Write availability and eventual read
+consistency and availability".
+
 =head1 SEE ALSO
 
 =over 4
