@@ -1,7 +1,7 @@
 package Yars::Routes;
 
 # ABSTRACT: set up the routes for Yars.
-our $VERSION = '1.21'; # VERSION
+our $VERSION = '1.22'; # VERSION
 
 
 use strict;
@@ -44,13 +44,6 @@ sub _get {
     my $filename = $c->stash("filename");
     my $md5      = $c->stash("md5");
 
-    if (my $secs = $c->param('zombie')) {
-        WARN "zombie alert.  Sleeping for $secs seconds.";
-        # test timeout limits
-        sleep $secs;
-        WARN "zombie is done sleeping for $secs seconds";
-    }
-
     return _head($c, @_) if $c->req->method eq 'HEAD';
 
     my $url = $c->tools->server_for($md5);
@@ -661,7 +654,7 @@ Yars::Routes - set up the routes for Yars.
 
 =head1 VERSION
 
-version 1.21
+version 1.22
 
 =head1 SYNOPSIS
 
